@@ -1,7 +1,7 @@
 package Neo4j::Bolt::Node;
 # ABSTRACT: Representation of Neo4j Node
 
-$Neo4j::Bolt::Node::VERSION = '0.10';
+$Neo4j::Bolt::Node::VERSION = '0.11';
 
 use strict;
 use warnings;
@@ -75,13 +75,12 @@ L<Neo4j::Bolt>
 
 =head1 AUTHOR
 
- Mark A. Jensen
- CPAN: MAJENSEN
- majensen -at- cpan -dot- org
+ Arne Johannessen
+ CPAN: AJNN
 
 =head1 LICENSE
 
-This software is Copyright (c) 2019-2020 by Mark A. Jensen.
+This software is Copyright (c) 2019-2020 by Arne Johannessen.
 
 This is free software, licensed under:
 
